@@ -532,7 +532,7 @@ class Oligo(NucleicAcid):
     def get_melting_temp(self):
         from Bio.SeqUtils import MeltingTemp
 
-        # If the TM is encoded in the oligo name, use that.
+        # If the Tm is encoded in the oligo name, use that.
         if m := re.search(r'[-_ ](TM|Tm|tm)=?(\d+)', self.name):
             return float(m.group(2))
 
@@ -556,6 +556,10 @@ class MakerInterface:
     # getters to be part of the interface.  Subclasses are free to use 
     # autoprop, though.
 
+    @classmethod
+    def make(self, db, products):
+        raise NotImplementedError
+
     @property
     def protocol(self):
         raise AttributeError
@@ -568,6 +572,11 @@ class MakerInterface:
     def dependencies(self):
         raise AttributeError
 
+    @property
+    def products(self):
+        # Required by make for "Label the product..." step.
+        raise AttributeError
+
     @property
     def product_tags(self):
         raise AttributeError
@@ -639,7 +648,8 @@ class IntermediateMixin:
             raise QueryError("no protocol specified", culprit=self)
 
         factory = load_maker_factory(key)
-        return one(factory([self]))
+        makers = list(factory(self.db, [self]))
+        return one(makers)
 
     def get_maker_args(self):
         if self.step == 0:
@@ -689,5 +699,10 @@ def load_db(use=None, config=None):
     return plugin.load(config_use)
 
 def load_maker_factory(key):
-    return MAKER_PLUGINS[key].make
+    try:
+        plugin = MAKER_PLUGINS[key].load()
+    except KeyError as err:
+        raise QueryError("no {err!r} maker plugins found")
+
+    return plugin.make
 
